raffle.distributions module
===========================

.. .. automodule:: raffle.Raffle__Distribs_Container
..    :members:
..    :undoc-members:
..    :show-inheritance:

.. autoclass:: raffle.Raffle__Distribs_Container
   :members:
   :undoc-members:
   :show-inheritance:
